#ifndef NSTD_CORE_H_INCLUDED
#define NSTD_CORE_H_INCLUDED
#include "core/arch.h"
#include "core/char_types.h"
#include "core/core.h"
#include "core/def.h"
#include "core/float_types.h"
#include "core/int_types.h"
#include "core/math.h"
#include "core/platform.h"
#include "core/pointer.h"
#include "core/slice.h"
#include "core/str.h"
#endif
